/********************************************************************************
** Form generated from reading UI file 'scoreswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SCORESWIDGET_H
#define UI_SCORESWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QTableView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ScoresWidget
{
public:
    QVBoxLayout *vboxLayout;
    QTableView *scoreTable;

    void setupUi(QWidget *ScoresWidget)
    {
        if (ScoresWidget->objectName().isEmpty())
            ScoresWidget->setObjectName("ScoresWidget");
        ScoresWidget->resize(256, 219);
        vboxLayout = new QVBoxLayout(ScoresWidget);
        vboxLayout->setObjectName("vboxLayout");
        scoreTable = new QTableView(ScoresWidget);
        scoreTable->setObjectName("scoreTable");
        scoreTable->setFrameShape(QFrame::StyledPanel);
        scoreTable->setFrameShadow(QFrame::Sunken);

        vboxLayout->addWidget(scoreTable);


        retranslateUi(ScoresWidget);

        QMetaObject::connectSlotsByName(ScoresWidget);
    } // setupUi

    void retranslateUi(QWidget *ScoresWidget)
    {
        ScoresWidget->setWindowTitle(tr2i18n("Scores", nullptr));
#if QT_CONFIG(whatsthis)
        scoreTable->setWhatsThis(tr2i18n("Scoreboard", nullptr));
#endif // QT_CONFIG(whatsthis)
    } // retranslateUi

};

namespace Ui {
    class ScoresWidget: public Ui_ScoresWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SCORESWIDGET_H

