/********************************************************************************
** Form generated from reading UI file 'prefs_ai.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PREFS_AI_H
#define UI_PREFS_AI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_prefs_ai
{
public:
    QGridLayout *gridLayout;
    QSpacerItem *spacerItem;
    KComboBox *kcfg_Difficulty;
    QLabel *label_difficulty;

    void setupUi(QWidget *prefs_ai)
    {
        if (prefs_ai->objectName().isEmpty())
            prefs_ai->setObjectName("prefs_ai");
        prefs_ai->resize(156, 46);
        gridLayout = new QGridLayout(prefs_ai);
        gridLayout->setObjectName("gridLayout");
        spacerItem = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(spacerItem, 1, 0, 1, 2);

        kcfg_Difficulty = new KComboBox(prefs_ai);
        kcfg_Difficulty->addItem(QString());
        kcfg_Difficulty->addItem(QString());
        kcfg_Difficulty->addItem(QString());
        kcfg_Difficulty->setObjectName("kcfg_Difficulty");
        kcfg_Difficulty->setEnabled(true);

        gridLayout->addWidget(kcfg_Difficulty, 0, 1, 1, 1);

        label_difficulty = new QLabel(prefs_ai);
        label_difficulty->setObjectName("label_difficulty");
        label_difficulty->setEnabled(true);

        gridLayout->addWidget(label_difficulty, 0, 0, 1, 1);

#if QT_CONFIG(shortcut)
        label_difficulty->setBuddy(kcfg_Difficulty);
#endif // QT_CONFIG(shortcut)

        retranslateUi(prefs_ai);

        QMetaObject::connectSlotsByName(prefs_ai);
    } // setupUi

    void retranslateUi(QWidget *prefs_ai)
    {
        prefs_ai->setWindowTitle(tr2i18n("AI Settings", nullptr));
        kcfg_Difficulty->setItemText(0, tr2i18n("Easy", nullptr));
        kcfg_Difficulty->setItemText(1, tr2i18n("Medium", nullptr));
        kcfg_Difficulty->setItemText(2, tr2i18n("Hard", nullptr));

#if QT_CONFIG(whatsthis)
        label_difficulty->setWhatsThis(tr2i18n("How difficult it will be to beat the computer", nullptr));
#endif // QT_CONFIG(whatsthis)
        label_difficulty->setText(tr2i18n("AI difficulty:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class prefs_ai: public Ui_prefs_ai {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PREFS_AI_H

