/********************************************************************************
** Form generated from reading UI file 'prefs_display.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PREFS_DISPLAY_H
#define UI_PREFS_DISPLAY_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcolorbutton.h"

QT_BEGIN_NAMESPACE

class Ui_prefs_display
{
public:
    QVBoxLayout *vboxLayout;
    QGroupBox *groupBox_2;
    QGridLayout *gridLayout;
    QLabel *label;
    KColorButton *kcfg_BackgroundColor;
    QLabel *label1;
    KColorButton *kcfg_CenterDotColor;
    QLabel *label2;
    KColorButton *kcfg_FeintLineColor;
    QLabel *label3;
    KColorButton *kcfg_LineColor;
    QLabel *label_2;
    KColorButton *kcfg_IndicatorLineColor;
    QLabel *label_3;
    KColorButton *kcfg_HighlightColor;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *prefs_display)
    {
        if (prefs_display->objectName().isEmpty())
            prefs_display->setObjectName("prefs_display");
        prefs_display->resize(245, 214);
        vboxLayout = new QVBoxLayout(prefs_display);
        vboxLayout->setObjectName("vboxLayout");
        groupBox_2 = new QGroupBox(prefs_display);
        groupBox_2->setObjectName("groupBox_2");
        gridLayout = new QGridLayout(groupBox_2);
        gridLayout->setObjectName("gridLayout");
        label = new QLabel(groupBox_2);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 0, 1, 1);

        kcfg_BackgroundColor = new KColorButton(groupBox_2);
        kcfg_BackgroundColor->setObjectName("kcfg_BackgroundColor");

        gridLayout->addWidget(kcfg_BackgroundColor, 0, 1, 1, 1);

        label1 = new QLabel(groupBox_2);
        label1->setObjectName("label1");

        gridLayout->addWidget(label1, 1, 0, 1, 1);

        kcfg_CenterDotColor = new KColorButton(groupBox_2);
        kcfg_CenterDotColor->setObjectName("kcfg_CenterDotColor");

        gridLayout->addWidget(kcfg_CenterDotColor, 1, 1, 1, 1);

        label2 = new QLabel(groupBox_2);
        label2->setObjectName("label2");

        gridLayout->addWidget(label2, 2, 0, 1, 1);

        kcfg_FeintLineColor = new KColorButton(groupBox_2);
        kcfg_FeintLineColor->setObjectName("kcfg_FeintLineColor");

        gridLayout->addWidget(kcfg_FeintLineColor, 2, 1, 1, 1);

        label3 = new QLabel(groupBox_2);
        label3->setObjectName("label3");

        gridLayout->addWidget(label3, 3, 0, 1, 1);

        kcfg_LineColor = new KColorButton(groupBox_2);
        kcfg_LineColor->setObjectName("kcfg_LineColor");

        gridLayout->addWidget(kcfg_LineColor, 3, 1, 1, 1);

        label_2 = new QLabel(groupBox_2);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 4, 0, 1, 1);

        kcfg_IndicatorLineColor = new KColorButton(groupBox_2);
        kcfg_IndicatorLineColor->setObjectName("kcfg_IndicatorLineColor");

        gridLayout->addWidget(kcfg_IndicatorLineColor, 4, 1, 1, 1);

        label_3 = new QLabel(groupBox_2);
        label_3->setObjectName("label_3");

        gridLayout->addWidget(label_3, 5, 0, 1, 1);

        kcfg_HighlightColor = new KColorButton(groupBox_2);
        kcfg_HighlightColor->setObjectName("kcfg_HighlightColor");

        gridLayout->addWidget(kcfg_HighlightColor, 5, 1, 1, 1);


        vboxLayout->addWidget(groupBox_2);

        spacerItem = new QSpacerItem(232, 71, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem);

#if QT_CONFIG(shortcut)
        label->setBuddy(kcfg_BackgroundColor);
        label1->setBuddy(kcfg_CenterDotColor);
        label2->setBuddy(kcfg_FeintLineColor);
        label3->setBuddy(kcfg_LineColor);
        label_2->setBuddy(kcfg_IndicatorLineColor);
        label_3->setBuddy(kcfg_HighlightColor);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(kcfg_LineColor, kcfg_IndicatorLineColor);

        retranslateUi(prefs_display);

        QMetaObject::connectSlotsByName(prefs_display);
    } // setupUi

    void retranslateUi(QWidget *prefs_display)
    {
        prefs_display->setWindowTitle(tr2i18n("Display Settings", nullptr));
#if QT_CONFIG(whatsthis)
        groupBox_2->setWhatsThis(tr2i18n("Settings for colors", nullptr));
#endif // QT_CONFIG(whatsthis)
        groupBox_2->setTitle(tr2i18n("Colors", nullptr));
#if QT_CONFIG(whatsthis)
        label->setWhatsThis(tr2i18n("Color of the drawn background", nullptr));
#endif // QT_CONFIG(whatsthis)
        label->setText(tr2i18n("Background color:", nullptr));
#if QT_CONFIG(whatsthis)
        label1->setWhatsThis(tr2i18n("Color of the drawn center dot", nullptr));
#endif // QT_CONFIG(whatsthis)
        label1->setText(tr2i18n("Center dot color:", nullptr));
#if QT_CONFIG(whatsthis)
        label2->setWhatsThis(tr2i18n("Color of the feintly drawn lines", nullptr));
#endif // QT_CONFIG(whatsthis)
        label2->setText(tr2i18n("Feint line color:", nullptr));
#if QT_CONFIG(whatsthis)
        label3->setWhatsThis(tr2i18n("Color of the drawn lines", nullptr));
#endif // QT_CONFIG(whatsthis)
        label3->setText(tr2i18n("Standard line color:", nullptr));
#if QT_CONFIG(whatsthis)
        label_2->setWhatsThis(tr2i18n("Color of the indicator lines", nullptr));
#endif // QT_CONFIG(whatsthis)
        label_2->setText(tr2i18n("Indicator line color:", nullptr));
#if QT_CONFIG(whatsthis)
        label_3->setWhatsThis(tr2i18n("Color of the indicator lines", nullptr));
#endif // QT_CONFIG(whatsthis)
        label_3->setText(tr2i18n("Highlight color:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class prefs_display: public Ui_prefs_display {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PREFS_DISPLAY_H

